@@ -22,7 +22,7 @@ use Carp;
 use Excel::Writer::XLSX::Chart;
 
 our @ISA     = qw(Excel::Writer::XLSX::Chart);
-our $VERSION = '0.18';
+our $VERSION = '0.19';
 
 
 ###############################################################################
@@ -68,6 +68,9 @@ sub _write_scatter_chart {
 
     my $self = shift;
 
+    # Add default formatting to the series data.
+    $self->_modify_series_formatting();
+
     $self->{_writer}->startTag( 'c:scatterChart' );
 
     # Write the c:scatterStyle element.
@@ -106,10 +109,16 @@ sub _write_ser {
     $self->_write_series_name( $series );
 
     # Write the c:spPr element.
-    $self->_write_sp_pr();
+    $self->_write_sp_pr( $series );
 
     # Write the c:marker element.
-    $self->_write_marker();
+    $self->_write_marker( $series->{_marker} );
+
+    # Write the c:dLbls element.
+    $self->_write_d_lbls( $series->{_labels} );
+
+    # Write the c:trendline element.
+    $self->_write_trendline( $series->{_trendline} );
 
     # Write the c:xVal element.
     $self->_write_x_val( $series );
@@ -117,7 +126,6 @@ sub _write_ser {
     # Write the c:yVal element.
     $self->_write_y_val( $series );
 
-
     $self->{_writer}->endTag( 'c:ser' );
 }
 
@@ -241,6 +249,30 @@ sub _write_scatter_style {
 }
 
 
+##############################################################################
+#
+# _modify_series_formatting()
+#
+# Add default formatting to the series data.
+#
+sub _modify_series_formatting {
+
+    my $self = shift;
+
+    my $index = 0;
+    for my $series ( @{ $self->{_series} } ) {
+        if ( !$series->{_line}->{_defined} ) {
+            $series->{_line} = {
+                width    => 2.25,
+                none     => 1,
+                _defined => 1,
+            };
+        }
+        $index++;
+    }
+}
+
+
 1;
 
 
