@@ -21,7 +21,7 @@ use Carp;
 use Excel::Writer::XLSX::Package::XMLwriter;
 
 our @ISA     = qw(Excel::Writer::XLSX::Package::XMLwriter);
-our $VERSION = '0.18';
+our $VERSION = '0.19';
 
 
 ###############################################################################
@@ -235,6 +235,23 @@ sub _add_calc_chain {
 }
 
 
+###############################################################################
+#
+# _add_image_types()
+#
+# Add the image default types.
+#
+sub _add_image_types {
+
+    my $self  = shift;
+    my %types = @_;
+
+    for my $type ( keys %types ) {
+        $self->_add_default( $type, 'image/' . $type );
+    }
+}
+
+
 ###############################################################################
 #
 # Internal methods.
